@@ -106,6 +106,37 @@ removed on a per-channel basis using
 :func:`satpy.readers.utils.remove_earthsun_distance_correction`.
 
 
+Metadata
+^^^^^^^^
+
+The SEVIRI L1.5 readers provide the following metadata:
+
+* The ``orbital_parameters`` attribute provides the nominal and actual satellite
+  position, as well as the projection centre. See the `Metadata` section in
+  the :doc:`../readers` chapter for more information.
+* The ``raw_metadata`` attribute provides raw metadata from the file header
+  (HRIT and Native format). By default, arrays with more than 100 elements are
+  excluded to limit memory usage. This threshold can be adjusted using the
+  ``mda_max_array_size`` reader keyword argument:
+
+  .. code-block:: python
+
+       scene = satpy.Scene(filenames,
+                          reader='seviri_l1b_hrit/native',
+                          reader_kwargs={'mda_max_array_size': 1000})
+
+* The ``acq_time`` coordinate provides the mean acquisition time for each
+  scanline. Use a ``MultiIndex`` to enable selection by acquisition time:
+
+  .. code-block:: python
+
+      import pandas as pd
+      mi = pd.MultiIndex.from_arrays([scn['IR_108']['y'].data, scn['IR_108']['acq_time'].data],
+                                     names=('y_coord', 'time'))
+      scn['IR_108']['y'] = mi
+      scn['IR_108'].sel(time=np.datetime64('2019-03-01T12:06:13.052000000'))
+
+
 References:
     - `MSG Level 1.5 Image Data Format Description`_
     - `Radiometric Calibration of MSG SEVIRI Level 1.5 Image Data in Equivalent Spectral Blackbody Radiance`_
@@ -121,9 +152,12 @@ References:
 
 """
 
+import warnings
+
 import numpy as np
 from numpy.polynomial.chebyshev import Chebyshev
 import dask.array as da
+import pyproj
 
 from satpy.readers.utils import apply_earthsun_distance_correction
 from satpy.readers.eum_base import (time_cds_short,
@@ -334,6 +368,13 @@ def get_cds_time(days, msecs):
     return time
 
 
+def add_scanline_acq_time(dataset, acq_time):
+    """Add scanline acquisition time to the given dataset."""
+    dataset.coords['acq_time'] = ('y', acq_time)
+    dataset.coords['acq_time'].attrs[
+        'long_name'] = 'Mean scanline acquisition time'
+
+
 def dec10216(inbuf):
     """Decode 10 bits data into 16 bits words.
 
@@ -582,6 +623,206 @@ def chebyshev(coefs, time, domain):
     return Chebyshev(coefs, domain=domain)(time) - 0.5 * coefs[0]
 
 
+def chebyshev_3d(coefs, time, domain):
+    """Evaluate Chebyshev Polynomials for three dimensions (x, y, z).
+
+    Expects the three coefficient sets to be defined in the same domain.
+
+    Args:
+        coefs: (x, y, z) coefficient sets.
+        time: See :func:`chebyshev`
+        domain: See :func:`chebyshev`
+
+    Returns:
+        Polynomials evaluated in (x, y, z) dimension.
+    """
+    x_coefs, y_coefs, z_coefs = coefs
+    x = chebyshev(x_coefs, time, domain)
+    y = chebyshev(y_coefs, time, domain)
+    z = chebyshev(z_coefs, time, domain)
+    return x, y, z
+
+
+class NoValidOrbitParams(Exception):
+    """Exception when validOrbitParameters are missing."""
+
+    pass
+
+
+class OrbitPolynomial:
+    """Polynomial encoding the satellite position.
+
+    Satellite position as a function of time is encoded in the coefficients
+    of an 8th-order Chebyshev polynomial.
+    """
+
+    def __init__(self, coefs, start_time, end_time):
+        """Initialize the polynomial."""
+        self.coefs = coefs
+        self.start_time = start_time
+        self.end_time = end_time
+
+    def evaluate(self, time):
+        """Get satellite position in earth-centered cartesion coordinates.
+
+        Args:
+            time: Timestamp where to evaluate the polynomial
+
+        Returns:
+            Earth-centered cartesion coordinates (x, y, z) in meters
+        """
+        domain = [np.datetime64(self.start_time).astype('int64'),
+                  np.datetime64(self.end_time).astype('int64')]
+        time = np.datetime64(time).astype('int64')
+        x, y, z = chebyshev_3d(self.coefs, time, domain)
+        return x * 1000, y * 1000, z * 1000  # km -> m
+
+    def __eq__(self, other):
+        """Test equality of two orbit polynomials."""
+        return (
+            np.array_equal(self.coefs, np.array(other.coefs)) and
+            self.start_time == other.start_time and
+            self.end_time == other.end_time
+        )
+
+
+def get_satpos(orbit_polynomial, time, semi_major_axis, semi_minor_axis):
+    """Get satellite position in geodetic coordinates.
+
+    Args:
+        orbit_polynomial: OrbitPolynomial instance
+        time: Timestamp where to evaluate the polynomial
+        semi_major_axis: Semi-major axis of the ellipsoid
+        semi_minor_axis: Semi-minor axis of the ellipsoid
+
+    Returns:
+        Longitude [deg east], Latitude [deg north] and Altitude [m]
+    """
+    x, y, z = orbit_polynomial.evaluate(time)
+    geocent = pyproj.CRS(
+        proj='geocent', a=semi_major_axis, b=semi_minor_axis, units='m'
+    )
+    latlong = pyproj.CRS(
+        proj='latlong', a=semi_major_axis, b=semi_minor_axis, units='m'
+    )
+    transformer = pyproj.Transformer.from_crs(geocent, latlong)
+    lon, lat, alt = transformer.transform(x, y, z)
+    return lon, lat, alt
+
+
+class OrbitPolynomialFinder:
+    """Find orbit polynomial for a given timestamp."""
+
+    def __init__(self, orbit_polynomials):
+        """Initialize with the given candidates.
+
+        Args:
+            orbit_polynomials: Dictionary of orbit polynomials as found in
+                               SEVIRI L1B files:
+
+                               .. code-block:: python
+
+                                   {'X': x_polynomials,
+                                    'Y': y_polynomials,
+                                    'Z': z_polynomials,
+                                    'StartTime': polynomials_valid_from,
+                                    'EndTime': polynomials_valid_to}
+
+        """
+        self.orbit_polynomials = orbit_polynomials
+        # Left/right boundaries of time intervals for which the polynomials are
+        # valid.
+        self.valid_from = orbit_polynomials['StartTime'][0, :].astype(
+            'datetime64[us]')
+        self.valid_to = orbit_polynomials['EndTime'][0, :].astype(
+            'datetime64[us]')
+
+    def get_orbit_polynomial(self, time, max_delta=6):
+        """Get orbit polynomial valid for the given time.
+
+        Orbit polynomials are only valid for certain time intervals. Find the
+        polynomial, whose corresponding interval encloses the given timestamp.
+        If there are multiple enclosing intervals, use the most recent one.
+        If there is no enclosing interval, find the interval whose centre is
+        closest to the given timestamp (but not more than ``max_delta`` hours
+        apart).
+
+        Why are there gaps between those intervals? Response from EUM:
+
+        A manoeuvre is a discontinuity in the orbit parameters. The flight
+        dynamic algorithms are not made to interpolate over the time-span of
+        the manoeuvre; hence we have elements describing the orbit before a
+        manoeuvre and a new set of elements describing the orbit after the
+        manoeuvre. The flight dynamic products are created so that there is
+        an intentional gap at the time of the manoeuvre. Also the two
+        pre-manoeuvre elements may overlap. But the overlap is not of an
+        issue as both sets of elements describe the same pre-manoeuvre orbit
+        (with negligible variations).
+        """
+        time = np.datetime64(time)
+        try:
+            match = self._get_enclosing_interval(time)
+        except ValueError:
+            warnings.warn(
+                'No orbit polynomial valid for {}. Using closest '
+                'match.'.format(time)
+            )
+            match = self._get_closest_interval_within(time, max_delta)
+        return OrbitPolynomial(
+            coefs=(
+                self.orbit_polynomials['X'][match],
+                self.orbit_polynomials['Y'][match],
+                self.orbit_polynomials['Z'][match]
+            ),
+            start_time=self.valid_from[match],
+            end_time=self.valid_to[match]
+        )
+
+    def _get_enclosing_interval(self, time):
+        """Find interval enclosing the given timestamp."""
+        enclosing = np.where(
+            np.logical_and(
+                time >= self.valid_from,
+                time < self.valid_to
+            )
+        )[0]
+        most_recent = np.argmax(self.valid_from[enclosing])
+        return enclosing[most_recent]
+
+    def _get_closest_interval_within(self, time, threshold):
+        """Find interval closest to the given timestamp within a given distance.
+
+        Args:
+            time: Timestamp of interest
+            threshold: Maximum distance between timestamp and interval center
+
+        Returns:
+            Index of closest interval
+        """
+        closest_match, distance = self._get_closest_interval(time)
+        threshold_diff = np.timedelta64(threshold, 'h')
+        if distance < threshold_diff:
+            return closest_match
+        raise NoValidOrbitParams(
+            'Unable to find orbit coefficients valid for {} +/- {}'
+            'hours'.format(time, threshold)
+        )
+
+    def _get_closest_interval(self, time):
+        """Find interval closest to the given timestamp.
+
+        Returns:
+            Index of closest interval, distance from its center
+        """
+        intervals_centre = self.valid_from + 0.5 * (
+                self.valid_to - self.valid_from
+        )
+        diffs_us = (time - intervals_centre).astype('i8')
+        closest_match = np.argmin(np.fabs(diffs_us))
+        distance = abs(intervals_centre[closest_match] - time)
+        return closest_match, distance
+
+
 def calculate_area_extent(area_dict):
     """Calculate the area extent seen by a geostationary satellite.
 
