@@ -28,6 +28,7 @@ import pytest
 import satpy
 import xarray as xr
 from satpy.readers import eps_l1b as eps
+from satpy._config import get_config_path
 from satpy.tests.utils import make_dataid
 
 grh_dtype = np.dtype([("record_class", "|i1"),
@@ -42,7 +43,8 @@ grh_dtype = np.dtype([("record_class", "|i1"),
 def create_sections(structure):
     """Create file sections."""
     sections = {}
-    form = eps.XMLFormat(os.path.join(eps.CONFIG_PATH, "eps_avhrrl1b_6.5.xml"))
+    format_fn = get_config_path("eps_avhrrl1b_6.5.xml")
+    form = eps.XMLFormat(format_fn)
     for count, (rec_class, sub_class) in structure:
         try:
             the_dtype = form.dtype((rec_class, sub_class))
