@@ -231,7 +231,7 @@ class TestViiNCBaseFileHandler(unittest.TestCase):
 
         # Checks that the _perform_interpolation function is correctly executed
         variable = xr.DataArray(
-            dims=('x', 'y'),
+            dims=('y', 'x'),
             name='test_name',
             attrs={
                 'key_1': 'value_1',
@@ -254,7 +254,7 @@ class TestViiNCBaseFileHandler(unittest.TestCase):
 
         # Checks that the _perform_geo_interpolation function is correctly executed
         variable_lon = xr.DataArray(
-            dims=('x', 'y'),
+            dims=('y', 'x'),
             name='test_lon',
             attrs={
                 'key_1': 'value_lon_1',
@@ -263,7 +263,7 @@ class TestViiNCBaseFileHandler(unittest.TestCase):
             data=np.zeros((10, 100))
         )
         variable_lat = xr.DataArray(
-            dims=('x', 'y'),
+            dims=('y', 'x'),
             name='test_lat',
             attrs={
                 'key_1': 'value_lat_1',
@@ -297,6 +297,22 @@ class TestViiNCBaseFileHandler(unittest.TestCase):
         self.assertEqual(return_lat.name, 'test_lat')
         self.assertEqual(return_lat.dims, ('num_pixels', 'num_lines'))
 
+    def test_standardize_dims(self):
+        """Test the standardize dims function."""
+        test_variable = xr.DataArray(
+            dims=('num_pixels', 'num_lines'),
+            name='test_data',
+            attrs={
+                'key_1': 'value_lat_1',
+                'key_2': 'value_lat_2'
+            },
+            data=np.ones((10, 100)) * 1.
+        )
+        out_variable = self.reader._standardize_dims(test_variable)
+        self.assertTrue(np.allclose(out_variable.values, np.ones((100, 10))))
+        self.assertEqual(out_variable.dims, ('y', 'x'))
+        self.assertEqual(out_variable.attrs['key_1'], 'value_lat_1')
+
     @mock.patch('satpy.readers.vii_base_nc.ViiNCBaseFileHandler._perform_calibration')
     @mock.patch('satpy.readers.vii_base_nc.ViiNCBaseFileHandler._perform_interpolation')
     @mock.patch('satpy.readers.vii_base_nc.ViiNCBaseFileHandler._perform_orthorectification')
@@ -309,8 +325,8 @@ class TestViiNCBaseFileHandler(unittest.TestCase):
         pi_.assert_not_called()
         po_.assert_not_called()
 
-        self.assertTrue(np.allclose(variable.values, np.ones((10, 100))))
-        self.assertEqual(variable.dims, ('num_pixels', 'num_lines'))
+        self.assertTrue(np.allclose(variable.values, np.ones((100, 10))))
+        self.assertEqual(variable.dims, ('y', 'x'))
         self.assertEqual(variable.attrs['test_attr'], 'attr')
         self.assertEqual(variable.attrs['units'], None)
 
