@@ -914,10 +914,6 @@ class TestStaticImageCompositor(unittest.TestCase):
         with self.assertRaises(ValueError):
             StaticImageCompositor("name")
 
-        # No absolute filename and no URL
-        with self.assertRaises(ValueError):
-            StaticImageCompositor("name", filename="foo.tif")
-
         # No area defined
         comp = StaticImageCompositor("name", filename="/foo.tif")
         self.assertEqual(comp._cache_filename, "/foo.tif")
@@ -935,7 +931,10 @@ class TestStaticImageCompositor(unittest.TestCase):
     @mock.patch('satpy.Scene')
     def test_call(self, Scene, register, retrieve):  # noqa
         """Test the static compositing."""
+        import satpy
         from satpy.composites import StaticImageCompositor
+
+        satpy.config.set(data_dir=os.path.join(os.path.sep, 'path', 'to', 'image'))
         remote_tif = "http://example.com/foo.tif"
 
         class MockScene(dict):
@@ -990,6 +989,19 @@ class TestStaticImageCompositor(unittest.TestCase):
         comp = StaticImageCompositor("name", filename="${TEST_IMAGE_PATH}/foo.tif", area='euro4')
         self.assertEqual(comp._cache_filename, "/path/to/image/foo.tif")
 
+        # URL and filename without absolute path
+        comp = StaticImageCompositor("name", url=remote_tif, filename="bar.tif")
+        self.assertEqual(comp._url, remote_tif)
+        self.assertEqual(comp._cache_filename, "bar.tif")
+
+        # No URL, filename without absolute path, use default data_dir from config
+        with mock.patch('os.path.exists') as exists:
+            exists.return_value = True
+            comp = StaticImageCompositor("name", filename="foo.tif")
+            self.assertEqual(comp._url, None)
+            self.assertEqual(comp._cache_filename,
+                             os.path.join(os.path.sep, 'path', 'to', 'image', 'foo.tif'))
+
 
 def _enhance2dataset(dataset, convert_p=False):
     """Mock the enhance2dataset to return the original data."""
