@@ -20,53 +20,23 @@
 
 import logging
 import os
-import re
 import warnings
+import contextlib
+from typing import Mapping
+
 import numpy as np
-import configparser
+import yaml
+from yaml import BaseLoader
+
+try:
+    from yaml import UnsafeLoader
+except ImportError:
+    from yaml import Loader as UnsafeLoader
 
 _is_logging_on = False
 TRACE_LEVEL = 5
 
 
-class OrderedConfigParser(object):
-    """Intercepts read and stores ordered section names.
-
-    Cannot use inheritance and super as ConfigParser use old style classes.
-    """
-
-    def __init__(self, *args, **kwargs):
-        """Initialize the instance."""
-        self.config_parser = configparser.ConfigParser(*args, **kwargs)
-
-    def __getattr__(self, name):
-        """Get the attribute."""
-        return getattr(self.config_parser, name)
-
-    def read(self, filename):
-        """Read config file."""
-        try:
-            conf_file = open(filename, 'r')
-            config = conf_file.read()
-            config_keys = re.findall(r'\[.*\]', config)
-            self.section_keys = [key[1:-1] for key in config_keys]
-        except IOError as e:
-            # Pass if file not found
-            if e.errno != 2:
-                raise
-        finally:
-            conf_file.close()
-
-        return self.config_parser.read(filename)
-
-    def sections(self):
-        """Get sections from config file."""
-        try:
-            return self.section_keys
-        except:  # noqa: E722
-            return self.config_parser.sections()
-
-
 def ensure_dir(filename):
     """Check if the dir of f exists, otherwise create it."""
     directory = os.path.dirname(filename)
@@ -74,9 +44,55 @@ def ensure_dir(filename):
         os.makedirs(directory)
 
 
-def debug_on():
-    """Turn debugging logging on."""
+def debug_on(deprecation_warnings=True):
+    """Turn debugging logging on.
+
+    Sets up a StreamHandler to to `sys.stderr` at debug level for all
+    loggers, such that all debug messages (and log messages with higher
+    severity) are logged to the standard error stream.
+
+    By default, since Satpy 0.26, this also enables the global visibility
+    of deprecation warnings.  This can be suppressed by passing a false
+    value.
+
+    Args:
+        deprecation_warnings (Optional[bool]): Switch on deprecation warnings.
+            Defaults to True.
+
+    Returns:
+        None
+    """
     logging_on(logging.DEBUG)
+    if deprecation_warnings:
+        deprecation_warnings_on()
+
+
+def debug_off():
+    """Turn debugging logging off.
+
+    This disables both debugging logging and the global visibility of
+    deprecation warnings.
+    """
+    logging_off()
+    deprecation_warnings_off()
+
+
+@contextlib.contextmanager
+def debug(deprecation_warnings=True):
+    """Context manager to temporarily set debugging on.
+
+    Example::
+
+        >>> with satpy.utils.debug():
+        ...     code_here()
+
+    Args:
+        deprecation_warnings (Optional[bool]): Switch on deprecation warnings.
+            Defaults to True.
+    """
+    debug_on(deprecation_warnings=deprecation_warnings)
+    yield
+    debug_off()
 
 
 def trace_on():
@@ -84,6 +100,27 @@ def trace_on():
     logging_on(TRACE_LEVEL)
 
 
+class _WarningManager:
+    """Class to handle switching warnings on and off."""
+
+    filt = None
+
+
+_warning_manager = _WarningManager()
+
+
+def deprecation_warnings_on():
+    """Switch on deprecation warnings."""
+    warnings.filterwarnings("default", category=DeprecationWarning)
+    _warning_manager.filt = warnings.filters[0]
+
+
+def deprecation_warnings_off():
+    """Switch off deprecation warnings."""
+    if _warning_manager.filt in warnings.filters:
+        warnings.filters.remove(_warning_manager.filt)
+
+
 def logging_on(level=logging.WARNING):
     """Turn logging on."""
     global _is_logging_on
@@ -327,3 +364,96 @@ def get_satpos(dataset):
         alt = dataset.attrs['satellite_altitude']
 
     return lon, lat, alt
+
+
+def recursive_dict_update(d, u):
+    """Recursive dictionary update.
+
+    Copied from:
+
+        http://stackoverflow.com/questions/3232943/update-value-of-a-nested-dictionary-of-varying-depth
+
+    """
+    for k, v in u.items():
+        if isinstance(v, Mapping):
+            r = recursive_dict_update(d.get(k, {}), v)
+            d[k] = r
+        else:
+            d[k] = u[k]
+    return d
+
+
+def _check_yaml_configs(configs, key):
+    """Get a diagnostic for the yaml *configs*.
+
+    *key* is the section to look for to get a name for the config at hand.
+    """
+    diagnostic = {}
+    for i in configs:
+        for fname in i:
+            with open(fname, 'r', encoding='utf-8') as stream:
+                try:
+                    res = yaml.load(stream, Loader=UnsafeLoader)
+                    msg = 'ok'
+                except yaml.YAMLError as err:
+                    stream.seek(0)
+                    res = yaml.load(stream, Loader=BaseLoader)
+                    if err.context == 'while constructing a Python object':
+                        msg = err.problem
+                    else:
+                        msg = 'error'
+                finally:
+                    try:
+                        diagnostic[res[key]['name']] = msg
+                    except (KeyError, TypeError):
+                        # this object doesn't have a 'name'
+                        pass
+    return diagnostic
+
+
+def _check_import(module_names):
+    """Import the specified modules and provide status."""
+    diagnostics = {}
+    for module_name in module_names:
+        try:
+            __import__(module_name)
+            res = 'ok'
+        except ImportError as err:
+            res = str(err)
+        diagnostics[module_name] = res
+    return diagnostics
+
+
+def check_satpy(readers=None, writers=None, extras=None):
+    """Check the satpy readers and writers for correct installation.
+
+    Args:
+        readers (list or None): Limit readers checked to those specified
+        writers (list or None): Limit writers checked to those specified
+        extras (list or None): Limit extras checked to those specified
+
+    Returns: bool
+        True if all specified features were successfully loaded.
+
+    """
+    from satpy.readers import configs_for_reader
+    from satpy.writers import configs_for_writer
+
+    print('Readers')
+    print('=======')
+    for reader, res in sorted(_check_yaml_configs(configs_for_reader(reader=readers), 'reader').items()):
+        print(reader + ': ', res)
+    print()
+
+    print('Writers')
+    print('=======')
+    for writer, res in sorted(_check_yaml_configs(configs_for_writer(writer=writers), 'writer').items()):
+        print(writer + ': ', res)
+    print()
+
+    print('Extras')
+    print('======')
+    module_names = extras if extras is not None else ('cartopy', 'geoviews')
+    for module_name, res in sorted(_check_import(module_names).items()):
+        print(module_name + ': ', res)
+    print()
