@@ -34,11 +34,12 @@ try:
 except ImportError:
     from yaml import Loader as UnsafeLoader
 
-from satpy.config import (config_search_paths, glob_config,
-                          get_environ_config_dir, recursive_dict_update)
+from satpy._config import config_search_paths, glob_config
+from satpy.utils import recursive_dict_update
 from satpy import CHUNK_SIZE
 from satpy.plugin_base import Plugin
 from satpy.resample import get_area_def
+from satpy.aux_download import DataDownloadMixin
 
 from trollsift import parser
 
@@ -65,8 +66,7 @@ def read_writer_config(config_files, loader=UnsafeLoader):
     return writer_info
 
 
-def load_writer_configs(writer_configs, ppp_config_dir,
-                        **writer_kwargs):
+def load_writer_configs(writer_configs, **writer_kwargs):
     """Load the writer from the provided `writer_configs`."""
     try:
         writer_info = read_writer_config(writer_configs)
@@ -75,59 +75,49 @@ def load_writer_configs(writer_configs, ppp_config_dir,
         raise ValueError("Invalid writer configs: "
                          "'{}'".format(writer_configs))
     init_kwargs, kwargs = writer_class.separate_init_kwargs(writer_kwargs)
-    writer = writer_class(ppp_config_dir=ppp_config_dir,
-                          config_files=writer_configs,
+    writer = writer_class(config_files=writer_configs,
                           **init_kwargs)
     return writer, kwargs
 
 
-def load_writer(writer, ppp_config_dir=None, **writer_kwargs):
+def load_writer(writer, **writer_kwargs):
     """Find and load writer `writer` in the available configuration files."""
-    if ppp_config_dir is None:
-        ppp_config_dir = get_environ_config_dir()
-
     config_fn = writer + ".yaml" if "." not in writer else writer
-    config_files = config_search_paths(
-        os.path.join("writers", config_fn), ppp_config_dir)
+    config_files = config_search_paths(os.path.join("writers", config_fn))
     writer_kwargs.setdefault("config_files", config_files)
     if not writer_kwargs['config_files']:
         raise ValueError("Unknown writer '{}'".format(writer))
 
     try:
         return load_writer_configs(writer_kwargs['config_files'],
-                                   ppp_config_dir=ppp_config_dir,
                                    **writer_kwargs)
     except ValueError:
         raise ValueError("Writer '{}' does not exist or could not be "
                          "loaded".format(writer))
 
 
-def configs_for_writer(writer=None, ppp_config_dir=None):
+def configs_for_writer(writer=None):
     """Generate writer configuration files for one or more writers.
 
     Args:
         writer (Optional[str]): Yield configs only for this writer
-        ppp_config_dir (Optional[str]): Additional configuration directory
-            to search for writer configuration files.
 
     Returns: Generator of lists of configuration files
 
     """
-    search_paths = (ppp_config_dir,) if ppp_config_dir else tuple()
     if writer is not None:
         if not isinstance(writer, (list, tuple)):
             writer = [writer]
         # given a config filename or writer name
         config_files = [w if w.endswith('.yaml') else w + '.yaml' for w in writer]
     else:
-        writer_configs = glob_config(os.path.join('writers', '*.yaml'),
-                                     *search_paths)
+        writer_configs = glob_config(os.path.join('writers', '*.yaml'))
         config_files = set(writer_configs)
 
     for config_file in config_files:
         config_basename = os.path.basename(config_file)
         writer_configs = config_search_paths(
-            os.path.join("writers", config_basename), *search_paths)
+            os.path.join("writers", config_basename))
 
         if not writer_configs:
             LOG.warning("No writer configs found for '%s'", writer)
@@ -402,13 +392,12 @@ def add_decorate(orig, fill_value=None, **decorate):
     return img
 
 
-def get_enhanced_image(dataset, ppp_config_dir=None, enhance=None, enhancement_config_file=None,
-                       overlay=None, decorate=None, fill_value=None):
+def get_enhanced_image(dataset, enhance=None, overlay=None, decorate=None,
+                       fill_value=None):
     """Get an enhanced version of `dataset` as an :class:`~trollimage.xrimage.XRImage` instance.
 
     Args:
         dataset (xarray.DataArray): Data to be enhanced and converted to an image.
-        ppp_config_dir (str): Root configuration directory.
         enhance (bool or Enhancer): Whether to automatically enhance
             data to be more visually useful and to fit inside the file
             format being saved to. By default this will default to using
@@ -417,7 +406,6 @@ def get_enhanced_image(dataset, ppp_config_dir=None, enhance=None, enhancement_c
             `False` so that no enhancments are performed. This can also
             be an instance of the :class:`~satpy.writers.Enhancer` class
             if further custom enhancement is needed.
-        enhancement_config_file (str): Deprecated.
         overlay (dict): Options for image overlays. See :func:`add_overlay`
             for available options.
         decorate (dict): Options for decorating the image. See
@@ -437,19 +425,12 @@ def get_enhanced_image(dataset, ppp_config_dir=None, enhance=None, enhancement_c
         instead.
 
     """
-    if ppp_config_dir is None:
-        ppp_config_dir = get_environ_config_dir()
-
-    if enhancement_config_file is not None:
-        warnings.warn("'enhancement_config_file' has been deprecated. Pass an instance of the "
-                      "'Enhancer' class to the 'enhance' keyword argument instead.", DeprecationWarning)
-
     if enhance is False:
         # no enhancement
         enhancer = None
     elif enhance is None or enhance is True:
         # default enhancement
-        enhancer = Enhancer(ppp_config_dir, enhancement_config_file)
+        enhancer = Enhancer()
     else:
         # custom enhancer
         enhancer = enhance
@@ -558,7 +539,7 @@ def compute_writer_results(results):
                 target.close()
 
 
-class Writer(Plugin):
+class Writer(Plugin, DataDownloadMixin):
     """Base Writer class for all other writers.
 
     A minimal writer subclass should implement the `save_dataset` method.
@@ -610,6 +591,7 @@ class Writer(Plugin):
             raise ValueError("Writer 'name' not provided")
 
         self.filename_parser = self.create_filename_parser(base_dir)
+        self.register_data_files()
 
     @classmethod
     def separate_init_kwargs(cls, kwargs):
@@ -645,6 +627,11 @@ class Writer(Plugin):
             file_pattern = self.file_pattern
         return parser.Parser(file_pattern) if file_pattern else None
 
+    @staticmethod
+    def _prepare_metadata_for_filename_formatting(attrs):
+        if isinstance(attrs.get('sensor'), set):
+            attrs['sensor'] = '-'.join(sorted(attrs['sensor']))
+
     def get_filename(self, **kwargs):
         """Create a filename where output data will be saved.
 
@@ -655,6 +642,7 @@ class Writer(Plugin):
         """
         if self.filename_parser is None:
             raise RuntimeError("No filename pattern or specific filename provided")
+        self._prepare_metadata_for_filename_formatting(kwargs)
         output_filename = self.filename_parser.compose(kwargs)
         dirname = os.path.dirname(output_filename)
         if dirname and not os.path.isdir(dirname):
@@ -747,7 +735,7 @@ class Writer(Plugin):
 class ImageWriter(Writer):
     """Base writer for image file formats."""
 
-    def __init__(self, name=None, filename=None, base_dir=None, enhance=None, enhancement_config=None, **kwargs):
+    def __init__(self, name=None, filename=None, base_dir=None, enhance=None, **kwargs):
         """Initialize image writer object.
 
         Args:
@@ -776,7 +764,6 @@ class ImageWriter(Writer):
                 `False` so that no enhancments are performed. This can also
                 be an instance of the :class:`~satpy.writers.Enhancer` class
                 if further custom enhancement is needed.
-            enhancement_config (str): Deprecated.
 
             kwargs (dict): Additional keyword arguments to pass to the
                 :class:`~satpy.writer.Writer` base class.
@@ -789,18 +776,13 @@ class ImageWriter(Writer):
 
         """
         super(ImageWriter, self).__init__(name, filename, base_dir, **kwargs)
-        if enhancement_config is not None:
-            warnings.warn("'enhancement_config' has been deprecated. Pass an instance of the "
-                          "'Enhancer' class to the 'enhance' keyword argument instead.", DeprecationWarning)
-        else:
-            enhancement_config = self.info.get("enhancement_config", None)
-
         if enhance is False:
             # No enhancement
             self.enhancer = False
         elif enhance is None or enhance is True:
             # default enhancement
-            self.enhancer = Enhancer(ppp_config_dir=self.ppp_config_dir, enhancement_config_file=enhancement_config)
+            enhancement_config = self.info.get("enhancement_config", None)
+            self.enhancer = Enhancer(enhancement_config_file=enhancement_config)
         else:
             # custom enhancer
             self.enhancer = enhance
@@ -868,7 +850,7 @@ class DecisionTree(object):
     additional keys that could be useful when matched. This class will
     search these decisions and return the one with the most matching
     parameters to the attributes passed to the
-    :meth:`~satpy.writers.DecisionTree.find_match`` method.
+    :meth:`~satpy.writers.DecisionTree.find_match` method.
 
     Note that decision sections are provided as a dict instead of a list
     so that they can be overwritten or updated by doing the equivalent
@@ -879,26 +861,28 @@ class DecisionTree(object):
         The returned match will be the first result found by searching
         provided `match_keys` in order.
 
-        decisions = {
-            'first_section': {
-                'a': 1,
-                'b': 2,
-                'useful_key': 'useful_value',
-            },
-            'second_section': {
-                'a': 5,
-                'useful_key': 'other_useful_value1',
-            },
-            'third_section': {
-                'b': 4,
-                'useful_key': 'other_useful_value2',
-            },
-        }
-        tree = DecisionTree(decisions, ('a', 'b'))
-        tree.find_match(a=5, b=2)  # second_section dict
-        tree.find_match(a=1, b=2)  # first_section dict
-        tree.find_match(a=5, b=4)  # second_section dict
-        tree.find_match(a=3, b=2)  # no match
+        ::
+
+            decisions = {
+                'first_section': {
+                    'a': 1,
+                    'b': 2,
+                    'useful_key': 'useful_value',
+                },
+                'second_section': {
+                    'a': 5,
+                    'useful_key': 'other_useful_value1',
+                },
+                'third_section': {
+                    'b': 4,
+                    'useful_key': 'other_useful_value2',
+                },
+            }
+            tree = DecisionTree(decisions, ('a', 'b'))
+            tree.find_match(a=5, b=2)  # second_section dict
+            tree.find_match(a=1, b=2)  # first_section dict
+            tree.find_match(a=5, b=4)  # second_section dict
+            tree.find_match(a=3, b=2)  # no match
 
     """
 
@@ -1099,21 +1083,19 @@ class EnhancementDecisionTree(DecisionTree):
 class Enhancer(object):
     """Helper class to get enhancement information for images."""
 
-    def __init__(self, ppp_config_dir=None, enhancement_config_file=None):
+    def __init__(self, enhancement_config_file=None):
         """Initialize an Enhancer instance.
 
         Args:
-            ppp_config_dir: Points to the base configuration directory
             enhancement_config_file: The enhancement configuration to apply, False to leave as is.
         """
-        self.ppp_config_dir = ppp_config_dir or get_environ_config_dir()
         self.enhancement_config_file = enhancement_config_file
         # Set enhancement_config_file to False for no enhancements
         if self.enhancement_config_file is None:
             # it wasn't specified in the config or in the kwargs, we should
             # provide a default
             config_fn = os.path.join("enhancements", "generic.yaml")
-            self.enhancement_config_file = config_search_paths(config_fn, self.ppp_config_dir)
+            self.enhancement_config_file = config_search_paths(config_fn)
 
         if not self.enhancement_config_file:
             # They don't want any automatic enhancements
@@ -1134,7 +1116,7 @@ class Enhancer(object):
 
         for sensor_name in sensor:
             config_fn = os.path.join("enhancements", sensor_name + ".yaml")
-            config_files = config_search_paths(config_fn, self.ppp_config_dir)
+            config_files = config_search_paths(config_fn)
             # Note: Enhancement configuration files can't overwrite individual
             # options, only entire sections are overwritten
             for config_file in config_files:
